@@ -486,6 +486,8 @@ build_notebook_for_panel (GeditPanel *panel)
 	/* Create the panel notebook */
 	panel->priv->notebook = gtk_notebook_new ();
 
+	gtk_notebook_set_show_border (GTK_NOTEBOOK (panel->priv->notebook),
+	                              FALSE);
 	gtk_notebook_set_tab_pos (GTK_NOTEBOOK (panel->priv->notebook),
 				  GTK_POS_BOTTOM);
 	gtk_notebook_set_scrollable (GTK_NOTEBOOK (panel->priv->notebook),
@@ -682,7 +684,10 @@ build_tab_label (GeditPanel  *panel,
 	gtk_container_add (GTK_CONTAINER (label_ebox), label_hbox);
 
 	/* setup icon */
-	gtk_box_pack_start (GTK_BOX (label_hbox), icon, FALSE, FALSE, 0);
+	if (icon != NULL)
+	{
+		gtk_box_pack_start (GTK_BOX (label_hbox), icon, FALSE, FALSE, 0);
+	}
 
 	/* setup label */
 	label = gtk_label_new (name);
@@ -772,21 +777,15 @@ gedit_panel_add_item (GeditPanel  *panel,
 	data = g_slice_new (GeditPanelItem);
 	data->id = g_strdup (id);
 	data->display_name = g_strdup (display_name);
+	data->icon = NULL;
 
-	if (image == NULL)
-	{
-		/* default to empty */
-		data->icon = gtk_image_new_from_icon_name ("text-x-generic",
-						           GTK_ICON_SIZE_MENU);
-	}
-	else
+	if (image != NULL)
 	{
 		data->icon = image;
+		gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
+		gtk_widget_set_size_request (data->icon, w, h);
 	}
 
-	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
-	gtk_widget_set_size_request (data->icon, w, h);
-
 	g_object_set_data (G_OBJECT (item),
 		           PANEL_ITEM_KEY,
 		           data);
