@@ -175,12 +175,20 @@ sync_state (GeditTab      *tab,
 		GdkPixbuf *pixbuf;
 
 		pixbuf = _gedit_tab_get_icon (tab);
-		gtk_image_set_from_pixbuf (GTK_IMAGE (tab_label->priv->icon), pixbuf);
 
 		if (pixbuf != NULL)
-			g_object_unref (pixbuf);
+		{
+			gtk_image_set_from_pixbuf (GTK_IMAGE (tab_label->priv->icon),
+			                           pixbuf);
 
-		gtk_widget_show (tab_label->priv->icon);
+			g_clear_object (&pixbuf);
+
+			gtk_widget_show (tab_label->priv->icon);
+		}
+		else
+		{
+			gtk_widget_hide (tab_label->priv->icon);
+		}
 
 		gtk_spinner_stop (GTK_SPINNER (tab_label->priv->spinner));
 		gtk_widget_hide (tab_label->priv->spinner);
@@ -294,14 +302,14 @@ gedit_tab_label_init (GeditTabLabel *tab_label)
 	gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
 	tab_label->priv->icon = icon;
 
-	label = gtk_label_new ("");
-	gtk_widget_set_halign (label, GTK_ALIGN_START);
-	gtk_misc_set_padding (GTK_MISC (label), 0, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-	tab_label->priv->label = label;
+	dummy_label = gtk_label_new ("  ");
+	gtk_box_pack_start (GTK_BOX (hbox), dummy_label, FALSE, FALSE, 0);
 
-	dummy_label = gtk_label_new ("");
-	gtk_box_pack_start (GTK_BOX (hbox), dummy_label, TRUE, TRUE, 0);
+	label = gtk_label_new ("");
+	gtk_widget_set_halign (label, GTK_ALIGN_CENTER);
+	gtk_misc_set_padding (GTK_MISC (label), 0, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+	tab_label->priv->label = label;
 
 	gtk_widget_show (ebox);
 	gtk_widget_show (hbox);
