@@ -1967,181 +1967,53 @@ _gedit_tab_get_tooltip (GeditTab *tab)
 	return tip;
 }
 
-static GdkPixbuf *
-resize_icon (GdkPixbuf *pixbuf,
-	     gint       size)
-{
-	gint width, height;
-
-	width = gdk_pixbuf_get_width (pixbuf);
-	height = gdk_pixbuf_get_height (pixbuf);
-
-	/* if the icon is larger than the nominal size, scale down */
-	if (MAX (width, height) > size)
-	{
-		GdkPixbuf *scaled_pixbuf;
-
-		if (width > height)
-		{
-			height = height * size / width;
-			width = size;
-		}
-		else
-		{
-			width = width * size / height;
-			height = size;
-		}
-
-		scaled_pixbuf = gdk_pixbuf_scale_simple	(pixbuf,
-							 width,
-							 height,
-							 GDK_INTERP_BILINEAR);
-		g_object_unref (pixbuf);
-		pixbuf = scaled_pixbuf;
-	}
-
-	return pixbuf;
-}
-
-static GdkPixbuf *
-get_stock_icon (GtkIconTheme *theme,
-		const gchar  *stock,
-		gint          size)
-{
-	GdkPixbuf *pixbuf;
-
-	pixbuf = gtk_icon_theme_load_icon (theme, stock, size, 0, NULL);
-	if (pixbuf == NULL)
-		return NULL;
-
-	return resize_icon (pixbuf, size);
-}
-
-static GdkPixbuf *
-get_icon (GtkIconTheme *theme,
-	  GFile        *location,
-	  gint          size)
-{
-	GdkPixbuf *pixbuf;
-	GtkIconInfo *icon_info;
-	GFileInfo *info;
-	GIcon *gicon;
-
-	if (location == NULL)
-		return get_stock_icon (theme, GTK_STOCK_FILE, size);
-
-	/* FIXME: Doing a sync stat is bad, this should be fixed */
-	info = g_file_query_info (location,
-	                          G_FILE_ATTRIBUTE_STANDARD_ICON,
-	                          G_FILE_QUERY_INFO_NONE,
-	                          NULL,
-	                          NULL);
-	if (info == NULL)
-		return get_stock_icon (theme, GTK_STOCK_FILE, size);
-
-	gicon = g_file_info_get_icon (info);
-
-	if (gicon == NULL)
-	{
-		g_object_unref (info);
-		return get_stock_icon (theme, GTK_STOCK_FILE, size);
-	}
-
-	icon_info = gtk_icon_theme_lookup_by_gicon (theme, gicon, size, 0);
-	g_object_unref (info);
-
-	if (icon_info == NULL)
-		return get_stock_icon (theme, GTK_STOCK_FILE, size);
-
-	pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
-	g_object_unref (icon_info);
-
-	if (pixbuf == NULL)
-		return get_stock_icon (theme, GTK_STOCK_FILE, size);
-
-	return resize_icon (pixbuf, size);
-}
-
-/* FIXME: add support for theme changed. I think it should be as easy as
-   call g_object_notify (tab, "name") when the icon theme changes */
 GdkPixbuf *
 _gedit_tab_get_icon (GeditTab *tab)
 {
-	GdkPixbuf *pixbuf;
-	GtkIconTheme *theme;
-	GdkScreen *screen;
-	gint icon_size;
+	const gchar *icon_name;
+	GdkPixbuf *pixbuf = NULL;
 
 	g_return_val_if_fail (GEDIT_IS_TAB (tab), NULL);
 
-	screen = gtk_widget_get_screen (GTK_WIDGET (tab));
-
-	theme = gtk_icon_theme_get_for_screen (screen);
-	g_return_val_if_fail (theme != NULL, NULL);
-
-	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, NULL, &icon_size);
-
 	switch (tab->priv->state)
 	{
-		case GEDIT_TAB_STATE_LOADING:
-			pixbuf = get_stock_icon (theme,
-						 GTK_STOCK_OPEN,
-						 icon_size);
-			break;
-
-		case GEDIT_TAB_STATE_REVERTING:
-			pixbuf = get_stock_icon (theme,
-						 GTK_STOCK_REVERT_TO_SAVED,
-						 icon_size);
-			break;
-
-		case GEDIT_TAB_STATE_SAVING:
-			pixbuf = get_stock_icon (theme,
-						 GTK_STOCK_SAVE,
-						 icon_size);
-			break;
-
 		case GEDIT_TAB_STATE_PRINTING:
-			pixbuf = get_stock_icon (theme,
-						 GTK_STOCK_PRINT,
-						 icon_size);
+			icon_name = "printer-printing-symbolic";
 			break;
 
 		case GEDIT_TAB_STATE_PRINT_PREVIEWING:
 		case GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW:
-			pixbuf = get_stock_icon (theme,
-						 GTK_STOCK_PRINT_PREVIEW,
-						 icon_size);
+			icon_name = "printer-symbolic";
 			break;
 
 		case GEDIT_TAB_STATE_LOADING_ERROR:
 		case GEDIT_TAB_STATE_REVERTING_ERROR:
 		case GEDIT_TAB_STATE_SAVING_ERROR:
 		case GEDIT_TAB_STATE_GENERIC_ERROR:
-			pixbuf = get_stock_icon (theme,
-						 GTK_STOCK_DIALOG_ERROR,
-						 icon_size);
+			icon_name = "dialog-error-symbolic";
 			break;
 
 		case GEDIT_TAB_STATE_EXTERNALLY_MODIFIED_NOTIFICATION:
-			pixbuf = get_stock_icon (theme,
-						 GTK_STOCK_DIALOG_WARNING,
-						 icon_size);
+			icon_name = "dialog-warning-symbolic";
 			break;
 
 		default:
-		{
-			GFile *location;
-			GeditDocument *doc;
+			icon_name = NULL;
+	}
 
-			doc = gedit_tab_get_document (tab);
+	if (icon_name != NULL)
+	{
+		GdkScreen *screen;
+		GtkIconTheme *theme;
+		gint icon_size;
 
-			location = gedit_document_get_location (doc);
-			pixbuf = get_icon (theme, location, icon_size);
+		screen = gtk_widget_get_screen (GTK_WIDGET (tab));
+		theme = gtk_icon_theme_get_for_screen (screen);
+		g_return_val_if_fail (theme != NULL, NULL);
 
-			if (location)
-				g_object_unref (location);
-		}
+		gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, NULL, &icon_size);
+
+		pixbuf = gtk_icon_theme_load_icon (theme, icon_name, icon_size, 0, NULL);
 	}
 
 	return pixbuf;
@@ -2489,11 +2361,6 @@ get_print_settings (GeditTab *tab)
 		settings = gtk_print_settings_copy (GTK_PRINT_SETTINGS (data));
 	}
 
-	/* Be sure the OUTPUT_URI is unset, because otherwise the
-	 * OUTPUT_BASENAME is not taken into account.
-	 */
-	gtk_print_settings_set (settings, GTK_PRINT_SETTINGS_OUTPUT_URI, NULL);
-
 	name = gedit_document_get_short_name_for_display (doc);
 	gtk_print_settings_set (settings, GTK_PRINT_SETTINGS_OUTPUT_BASENAME, name);
 
